@@ -33,6 +33,7 @@
 #include <KPluginFactory>
 #include <KWallet>
 #include <KWindowSystem>
+#include <KX11Extras>
 
 SecretAgent::SecretAgent(QObject *parent)
     : NetworkManager::SecretAgent(QStringLiteral("org.kde.plasma.networkmanagement"), NetworkManager::SecretAgent::Capability::VpnHints, parent)
@@ -189,8 +190,9 @@ void SecretAgent::dialogAccepted()
                 } else if (completeConnectionSettings->connectionType() == NetworkManager::ConnectionSettings::Wireless) {
                     NetworkManager::WirelessSecuritySetting::Ptr wirelessSecuritySetting =
                         completeConnectionSettings->setting(NetworkManager::Setting::WirelessSecurity).staticCast<NetworkManager::WirelessSecuritySetting>();
-                    if (wirelessSecuritySetting && wirelessSecuritySetting->keyMgmt() == NetworkManager::WirelessSecuritySetting::WpaEap
-                        || wirelessSecuritySetting->keyMgmt() == NetworkManager::WirelessSecuritySetting::WpaEapSuiteB192) {
+                    if (wirelessSecuritySetting
+                        && ((wirelessSecuritySetting->keyMgmt() == NetworkManager::WirelessSecuritySetting::WpaEap)
+                            || (wirelessSecuritySetting->keyMgmt() == NetworkManager::WirelessSecuritySetting::WpaEapSuiteB192))) {
                         NetworkManager::Security8021xSetting::Ptr security8021xSetting =
                             completeConnectionSettings->setting(NetworkManager::Setting::Security8021x).staticCast<NetworkManager::Security8021xSetting>();
                         if (security8021xSetting) {
@@ -437,8 +439,9 @@ bool SecretAgent::processGetSecrets(SecretsRequest &request) const
             request.dialog = m_dialog;
             request.saveSecretsWithoutReply = !connectionSettings->permissions().isEmpty();
             m_dialog->show();
-            KWindowSystem::setState(m_dialog->winId(), NET::KeepAbove);
-            KWindowSystem::forceActiveWindow(m_dialog->winId());
+            if (KWindowSystem::isPlatformX11()) {
+                KX11Extras::setState(m_dialog->winId(), NET::KeepAbove);
+            }
             return false;
         }
     } else if (isVpn && userRequested) { // just return what we have
@@ -658,3 +661,5 @@ void SecretAgent::importSecretsFromPlainTextFiles()
         }
     }
 }
+
+#include "moc_secretagent.cpp"
